@@ -1,4 +1,4 @@
-.onLoad <- function(libname, pkgname) {
+.onAttach <- function(libname, pkgname) {
   packageStartupMessage(
     paste("biwavelet", 
           utils::packageDescription("biwavelet",
